@@ -4,29 +4,6 @@ https://github.com/ppizarror/pygame-menu
 
 UTILS
 Utility functions.
-
-License:
--------------------------------------------------------------------------------
-The MIT License (MIT)
-Copyright 2017-2021 Pablo Pizarro R. @ppizarror
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the Software
-is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
--------------------------------------------------------------------------------
 """
 
 __all__ = [
@@ -329,6 +306,10 @@ def format_color(
     if not isinstance(color, ColorInputInstance):
         return color
     if not isinstance(color, pygame.Color):
+        if isinstance(color, str):
+            if len(color) == 4 and color[0] == '#':
+                r, g, b = color[1], color[2], color[3]
+                color = f'#{r * 2}{g * 2}{b * 2}'
         try:
             if isinstance(color, VectorInstance) and 3 <= len(color) <= 4:
                 if PYGAME_V2:
